==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/link/lang/ku.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'ku', {
	acccessKey: 'کلیلی دەستپێگەیشتن',
	advanced: 'پێشکەوتوو',
	advisoryContentType: 'جۆری ناوەڕۆکی ڕاویژکار',
	advisoryTitle: 'ڕاوێژکاری سەردێڕ',
	anchor: {
		toolbar: 'دانان/چاکسازی لەنگەر',
		menu: 'چاکسازی لەنگەر',
		title: 'خاسیەتی لەنگەر',
		name: 'ناوی لەنگەر',
		errorName: 'تکایه ناوی لەنگەر بنووسه',
		remove: 'لابردنی لەنگەر'
	},
	anchorId: 'بەپێی ناسنامەی توخم',
	anchorName: 'بەپێی ناوی لەنگەر',
	charset: 'بەستەری سەرچاوەی نووسە',
	cssClasses: 'شێوازی چینی پەڕه',
	emailAddress: 'ناونیشانی ئیمەیل',
	emailBody: 'ناوەڕۆکی نامە',
	emailSubject: 'بابەتی نامە',
	id: 'ناسنامە',
	info: 'زانیاری بەستەر',
	langCode: 'هێمای زمان',
	langDir: 'ئاراستەی زمان',
	langDirLTR: 'چەپ بۆ ڕاست (LTR)',
	langDirRTL: 'ڕاست بۆ چەپ (RTL)',
	menu: 'چاکسازی بەستەر',
	name: 'ناو',
	noAnchors: '(هیچ جۆرێکی لەنگەر ئامادە نیە لەم پەڕەیه)',
	noEmail: 'تکایە ناونیشانی ئیمەیل بنووسە',
	noUrl: 'تکایە ناونیشانی بەستەر بنووسە',
	other: '<هیتر>',
	popupDependent: 'پێوەبەستراو (Netscape)',
	popupFeatures: 'خاسیەتی پەنجەرەی سەرهەڵدەر',
	popupFullScreen: 'پڕ بەپڕی شاشە (IE)',
	popupLeft: 'جێگای چەپ',
	popupLocationBar: 'هێڵی ناونیشانی بەستەر',
	popupMenuBar: 'هێڵی لیسته',
	popupResizable: 'توانای گۆڕینی قەباره',
	popupScrollBars: 'هێڵی هاتووچۆپێکردن',
	popupStatusBar: 'هێڵی دۆخ',
	popupToolbar: 'هێڵی تووڵامراز',
	popupTop: 'جێگای سەرەوە',
	rel: 'پەیوەندی',
	selectAnchor: 'هەڵبژاردنی لەنگەرێك',
	styles: 'شێواز',
	tabIndex: 'بازدەری تابی  ئیندێکس',
	target: 'ئامانج',
	targetFrame: '<چووارچێوە>',
	targetFrameName: 'ناوی ئامانجی چووارچێوە',
	targetPopup: '<پەنجەرەی سەرهەڵدەر>',
	targetPopupName: 'ناوی پەنجەرەی سەرهەڵدەر',
	title: 'بەستەر',
	toAnchor: 'بەستەر بۆ لەنگەر له دەق',
	toEmail: 'ئیمەیل',
	toUrl: 'ناونیشانی بەستەر',
	toolbar: 'دانان/ڕێکخستنی بەستەر',
	type: 'جۆری بەستەر',
	unlink: 'لابردنی بەستەر',
	upload: 'بارکردن'
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/link/lang/ku.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'ku', {
	acccessKey: 'کلیلی دەستپێگەیشتن',
	advanced: 'پێشکەوتوو',
	advisoryContentType: 'جۆری ناوەڕۆکی ڕاویژکار',
	advisoryTitle: 'ڕاوێژکاری سەردێڕ',
	anchor: {
		toolbar: 'دانان/چاکسازی لەنگەر',
		menu: 'چاکسازی لەنگەر',
		title: 'خاسیەتی لەنگەر',
		name: 'ناوی لەنگەر',
		errorName: 'تکایه ناوی لەنگەر بنووسه',
		remove: 'لابردنی لەنگەر'
	},
	anchorId: 'بەپێی ناسنامەی توخم',
	anchorName: 'بەپێی ناوی لەنگەر',
	charset: 'بەستەری سەرچاوەی نووسە',
	cssClasses: 'شێوازی چینی پەڕه',
	download: 'داگرتنی بەهێز',
	displayText: 'پیشاندانی دەق',
	emailAddress: 'ناونیشانی ئیمەیل',
	emailBody: 'ناوەڕۆکی نامە',
	emailSubject: 'بابەتی نامە',
	id: 'ناسنامە',
	info: 'زانیاری بەستەر',
	langCode: 'هێمای زمان',
	langDir: 'ئاراستەی زمان',
	langDirLTR: 'چەپ بۆ ڕاست (LTR)',
	langDirRTL: 'ڕاست بۆ چەپ (RTL)',
	menu: 'چاکسازی بەستەر',
	name: 'ناو',
	noAnchors: '(هیچ جۆرێکی لەنگەر ئامادە نیە لەم پەڕەیه)',
	noEmail: 'تکایە ناونیشانی ئیمەیل بنووسە',
	noUrl: 'تکایە ناونیشانی بەستەر بنووسە',
	noTel: 'Please type the phone number', // MISSING
	other: '<هیتر>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'پێوەبەستراو (Netscape)',
	popupFeatures: 'خاسیەتی پەنجەرەی سەرهەڵدەر',
	popupFullScreen: 'پڕ بەپڕی شاشە (IE)',
	popupLeft: 'جێگای چەپ',
	popupLocationBar: 'هێڵی ناونیشانی بەستەر',
	popupMenuBar: 'هێڵی لیسته',
	popupResizable: 'توانای گۆڕینی قەباره',
	popupScrollBars: 'هێڵی هاتووچۆپێکردن',
	popupStatusBar: 'هێڵی دۆخ',
	popupToolbar: 'هێڵی تووڵامراز',
	popupTop: 'جێگای سەرەوە',
	rel: 'پەیوەندی',
	selectAnchor: 'هەڵبژاردنی لەنگەرێك',
	styles: 'شێواز',
	tabIndex: 'بازدەری تابی  ئیندێکس',
	target: 'ئامانج',
	targetFrame: '<چووارچێوە>',
	targetFrameName: 'ناوی ئامانجی چووارچێوە',
	targetPopup: '<پەنجەرەی سەرهەڵدەر>',
	targetPopupName: 'ناوی پەنجەرەی سەرهەڵدەر',
	title: 'بەستەر',
	toAnchor: 'بەستەر بۆ لەنگەر له دەق',
	toEmail: 'ئیمەیل',
	toUrl: 'ناونیشانی بەستەر',
	toPhone: 'Phone', // MISSING
	toolbar: 'دانان/ڕێکخستنی بەستەر',
	type: 'جۆری بەستەر',
	unlink: 'لابردنی بەستەر',
	upload: 'بارکردن'
} );
